package Bundle::CUFTS;

use strict;

our $VERSION = '0.07';

=head1 NAME

Bundle::CUFTS - All Perl modules required to run CUFTS.

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::CUFTS'>

=head1 DESCRIPTION

Installs everything you need to run CUFTS.

=head1 CONTENTS

Business::ISSN

Catalyst::Engine::Apache

Catalyst::Plugin::Session::Store::FastMmap

Catalyst::Plugin::Static::Simple

Catalyst::Plugin::FillInForm

Class::Accessor

Class::DBI

Class::DBI::AbstractSearch

Class::DBI::FromForm

Class::DBI::Plugin::CountSearch

Class::DBI::Sweet

Date::Calc

Exception::Class

Exception::Class::DBI

Getopt::Long

HTML::Entities

LWP::UserAgent

MARC::Record

MIME::Lite

Net::SMTP

SQL::Abstract

Task::Catalyst

Template

Term::Readline

Text::CSV

URI::Escape

=head1 AUTHOR

Todd Holbrook, C<tholbroo@sfu.ca>

=head1 LICENSE

This library is free software, you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut

1;
